#include "timezone.h"

TimeZone::TimeZone(QObject *parent) :
    QObject(parent)
{
}
/** @short helper property that returns a list of available IANA timezone id's */
QVariantList TimeZone::availableTimeZoneIds() const
{
    QVariantList timeZoneList;
    Q_FOREACH(const QByteArray &id, QTimeZone::availableTimeZoneIds()) {
        timeZoneList.append(QString(id));
    }
    return timeZoneList;
}

int TimeZone::getUtcOffsetFromTimeZoneId(const QByteArray &timeZoneId)
{
    QTimeZone tzone(timeZoneId);
    if (tzone.isValid()) {
        QDateTime tzOffset;
        tzOffset.setTimeSpec(Qt::TimeZone);
        tzOffset.setTimeZone(tzone);
        // Now return the offset from the current UTC time in hours
        return tzOffset.timeZone().offsetFromUtc(QDateTime::currentDateTimeUtc()) / 3600;
    } else {
        emit error(QString("Time zone id %1 is not a valid IANA timezone id").arg(QString(timeZoneId)));
        return 0;
    }
}
