#ifndef TIMEZONE_H
#define TIMEZONE_H

#include <QObject>
#include <QtQuick>
#include <QDateTime>
#include <QTimeZone>

/*
 * Usage:
 *
 * import QtQuick 2.2
 * import Ubuntu.Components 1.1
 * import TimeZone 1.0
 *
 * MainView {
 *      id: root
 *
 *      Label { text: i18n.tr("UTC offset for America/Phoenix is: %1").arg(parseInt(timeZone.getUtcOffsetFromTimeZoneId("America/Phoenix")) }
 *
 *      TimeZone {
 *          id: timeZone
 *      }
 *      ## Also the availalbe timezone ids can be used as a listmodel or a list to query using the usual
 *      ## list methods
 *      ListView {
 *          model: timeZone.availableTimeZoneIds
 *          delegate: Label {text: modelData}
 *      }
 *
 * */

class TimeZone : public QObject
{
    Q_OBJECT
    Q_PROPERTY(QVariantList availableTimeZoneIds READ availableTimeZoneIds CONSTANT)
public:
    explicit TimeZone(QObject *parent = 0);

    QVariantList availableTimeZoneIds() const;
    Q_INVOKABLE int getUtcOffsetFromTimeZoneId(const QByteArray &timeZoneId);

signals:
    void error(const QString &errorMsg);

};

#endif // TIMEZONE_H
